.. include:: globals.txt
.. _index:

================================
Django Regex
================================

Overview
========

.. image:: https://img.shields.io/travis/saxix/django-regex/master.svg
    :target: http://travis-ci.org/saxix/django-regex/
    :alt: Test status

.. image:: https://codecov.io/github/saxix/django-regex/coverage.svg?branch=master
    :target: https://codecov.io/github/saxix/django-regex?branch=master
    :alt: Coverage



Fields and utilities to work with regular expression in Django


Table Of Contents
=================

.. toctree::
    :maxdepth: 1

    install


Links
=====

   * Project home page: https://github.com/saxix/django-regex
   * Issue tracker: https://github.com/saxix/django-regex/issues?sort
   * Download: http://pypi.python.org/pypi/django-regex/
   * Docs: http://readthedocs.org/docs/django-regex/en/latest/
